@@ -1,6 +1,4 @@
-use criterion::{
-    criterion_group, criterion_main, BenchmarkId, Criterion, Throughput,
-};
+use criterion::{criterion_group, criterion_main, BenchmarkId, Criterion, Throughput};
 use std::time::{Duration, Instant};
 
 use nats;
@@ -16,20 +14,16 @@ pub fn pub_benchmark(c: &mut Criterion) {
     for size in [32, 128, 256, 1024, 4096, 8192].iter() {
         let nc = nats::connect("127.0.0.1").unwrap();
         let msg = &bmsg[0..*size];
-        group.bench_with_input(
-            BenchmarkId::from_parameter(size),
-            size,
-            |b, _| {
-                b.iter_custom(|n| {
-                    let start = Instant::now();
-                    for _i in 0..n {
-                        nc.publish("bench", &msg).unwrap();
-                    }
-                    nc.flush().unwrap();
-                    start.elapsed()
-                });
-            },
-        );
+        group.bench_with_input(BenchmarkId::from_parameter(size), size, |b, _| {
+            b.iter_custom(|n| {
+                let start = Instant::now();
+                for _i in 0..n {
+                    nc.publish("bench", &msg).unwrap();
+                }
+                nc.flush().unwrap();
+                start.elapsed()
+            });
+        });
     }
     group.finish();
 }
